import React from 'react';
import { MSC3906Rendezvous, RendezvousFailureReason } from 'matrix-js-sdk/src/rendezvous';
import { MatrixClient } from 'matrix-js-sdk/src/client';
/**
 * The intention of this enum is to have a mode that scans a QR code instead of generating one.
 */
export declare enum Mode {
    /**
     * A QR code with be generated and shown
     */
    Show = "show"
}
declare enum Phase {
    Loading = 0,
    ShowingQR = 1,
    Connecting = 2,
    Connected = 3,
    WaitingForDevice = 4,
    Verifying = 5,
    Error = 6
}
interface IProps {
    client: MatrixClient;
    mode: Mode;
    onFinished(...args: any): void;
}
interface IState {
    phase: Phase;
    rendezvous?: MSC3906Rendezvous;
    confirmationDigits?: string;
    failureReason?: RendezvousFailureReason;
    mediaPermissionError?: boolean;
}
/**
 * A component that allows sign in and E2EE set up with a QR code.
 *
 * It implements both `login.start` and `login-reciprocate` capabilities as well as both scanning and showing QR codes.
 *
 * This uses the unstable feature of MSC3906: https://github.com/matrix-org/matrix-spec-proposals/pull/3906
 */
export default class LoginWithQR extends React.Component<IProps, IState> {
    constructor(props: any);
    componentDidMount(): void;
    componentDidUpdate(prevProps: Readonly<IProps>): void;
    private updateMode;
    componentWillUnmount(): void;
    private approveLogin;
    private generateCode;
    private onFailure;
    reset(): void;
    private cancelClicked;
    private declineClicked;
    private tryAgainClicked;
    private onBackClick;
    private cancelButton;
    private simpleSpinner;
    render(): JSX.Element;
}
export {};
