import { MatrixClient, MatrixEvent } from "matrix-js-sdk/src/matrix";
import { TypedEventEmitter } from "matrix-js-sdk/src/models/typed-event-emitter";
import { IDestroyable } from "../../utils/IDestroyable";
import { VoiceBroadcastInfoState } from "..";
export declare enum VoiceBroadcastPlaybackState {
    Paused = 0,
    Playing = 1,
    Stopped = 2,
    Buffering = 3
}
export declare enum VoiceBroadcastPlaybackEvent {
    LengthChanged = "length_changed",
    StateChanged = "state_changed",
    InfoStateChanged = "info_state_changed"
}
interface EventMap {
    [VoiceBroadcastPlaybackEvent.LengthChanged]: (length: number) => void;
    [VoiceBroadcastPlaybackEvent.StateChanged]: (state: VoiceBroadcastPlaybackState, playback: VoiceBroadcastPlayback) => void;
    [VoiceBroadcastPlaybackEvent.InfoStateChanged]: (state: VoiceBroadcastInfoState) => void;
}
export declare class VoiceBroadcastPlayback extends TypedEventEmitter<VoiceBroadcastPlaybackEvent, EventMap> implements IDestroyable {
    readonly infoEvent: MatrixEvent;
    private client;
    private state;
    private infoState;
    private chunkEvents;
    private playbacks;
    private currentlyPlaying;
    private lastInfoEvent;
    private chunkRelationHelper;
    private infoRelationHelper;
    constructor(infoEvent: MatrixEvent, client: MatrixClient);
    private setUpRelationsHelper;
    private addChunkEvent;
    private addInfoEvent;
    private loadChunks;
    private enqueueChunk;
    private onPlaybackStateChange;
    private playNext;
    getLength(): number;
    start(): Promise<void>;
    get length(): number;
    stop(): void;
    pause(): void;
    resume(): void;
    /**
     * Toggles the playback:
     * stopped → playing
     * playing → paused
     * paused → playing
     */
    toggle(): Promise<void>;
    getState(): VoiceBroadcastPlaybackState;
    private setState;
    getInfoState(): VoiceBroadcastInfoState;
    private setInfoState;
    destroy(): void;
}
export {};
